#
# spec file for package terminology
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define e_branding_package %(rpm -q --qf '%%{name}' --whatprovides enlightenment-branding)
%if 0%{?suse_version} && 0%{?is_opensuse}
%define e_branding_version %(rpm -q --qf '%%{version}' %{e_branding_package})
%else
%define e_branding_version 0.1
%endif
Name:           terminology
Version:        1.13.0
Release:        1.7
Summary:        EFL based terminal emulator
License:        BSD-2-Clause AND OFL-1.1
Group:          System/X11/Terminals
URL:            https://enlightenment.org
Source:         https://download.enlightenment.org/rel/apps/terminology/%{name}-%{version}.tar.xz
Patch0:         fix-desktop.patch
# Creates a "Flat" colorscheme so we can ship the "Default" from branding packages
Patch1:         feature-flat-colorscheme.patch
BuildRequires:  ImageMagick
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.40.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ecore)
BuildRequires:  pkgconfig(ecore-evas)
BuildRequires:  pkgconfig(ecore-file)
BuildRequires:  pkgconfig(ecore-imf)
BuildRequires:  pkgconfig(ecore-imf-evas)
BuildRequires:  pkgconfig(ecore-input)
BuildRequires:  pkgconfig(ecore-ipc)
BuildRequires:  pkgconfig(edje)
BuildRequires:  pkgconfig(eet)
BuildRequires:  pkgconfig(efreet)
BuildRequires:  pkgconfig(eina)
BuildRequires:  pkgconfig(elementary) >= 1.8.0
BuildRequires:  pkgconfig(emotion)
BuildRequires:  pkgconfig(ethumb_client)
BuildRequires:  pkgconfig(evas)
Requires:       efl
Requires:       elementary >= 1.8.0
# provides default.edj
Requires:       terminology-theme-dft
Recommends:     %{name}-lang
Conflicts:      evas-generic-loaders < 1.8.0
%if 0%{?suse_version}
Recommends:     evas-generic-loaders >= 1.8.0
Recommends:     terminology-theme-Flat
Recommends:     terminology-theme-dark
Recommends:     terminology-theme-misc
Recommends:     terminology-theme-openSUSE
Recommends:     terminology-theme-openSUSE-oliveleaf
%endif
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%if 0%{?is_opensuse}
BuildRequires:  enlightenment-branding-openSUSE
%endif
%endif

%description
Fast and lightweight terminal emulator using EFL libraries.

%package theme-upstream
Summary:        Default Enlightenment theme
Group:          System/X11/Terminals
Conflicts:      otherproviders(terminology-theme-dft)
Provides:       terminology-theme = %{e_branding_version}
Provides:       terminology-theme-dft

%description  theme-upstream
For use with upstream branding, when using openSUSE themes, when using
openSUSE themes.

Use the Dark theme instead.

%package theme-Flat
Summary:        Default terminology theme(Flat)
Group:          System/X11/Terminals
Provides:       terminology-theme

%description  theme-Flat
The default theme for terminology install when using openSUSE branding.

%package theme-misc
Summary:        Miscellaneous terminology themes
Group:          System/X11/Terminals
Provides:       terminology-theme

%description  theme-misc
Miscellaneous themes provided by the terminology devs, includes Solarized,
Mild and Black themes.

%lang_package

%prep
%autosetup -p1

%build
export ECORE_NO_SYSTEM_MODULES=1
export CFLAGS="%{optflags} %{?mageia:-g}"
%meson
%meson_build

%install
%meson_install

sed -i 's/.png[[:blank:]]*$//' %{buildroot}%{_datadir}/applications/%{name}.desktop

# make 2 copys of default for branding
cp %{buildroot}%{_datadir}/%{name}/themes/default.edj %{buildroot}%{_datadir}/%{name}/themes/Flat.edj
# Colorscheme done with a patch

%find_lang %{name}
%if 0%{?suse_version}
%suse_update_desktop_file -r %{name} Enlightenment System TerminalEmulator
%fdupes %{buildroot}/%{_datadir}
%endif

%if 0%{?suse_version} < 1320
%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%{?suse_version:%files}
%{!?suse_version:%files -f %{name}.lang}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README*
%{_bindir}/%{name}
%{_bindir}/ty*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%{_mandir}/man?/terminology*.?z
%{_mandir}/man?/ty*.?z
%exclude %{_datadir}/%{name}/themes/*
%exclude %{_datadir}/%{name}/colorschemes/*

%files theme-upstream
%{_datadir}/%{name}/themes/default.edj
%{_datadir}/%{name}/colorschemes/Default.eet

%files theme-Flat
%{_datadir}/%{name}/themes/Flat.edj
%{_datadir}/%{name}/colorschemes/Flat.eet

%files theme-misc
%{_datadir}/%{name}/themes/*
%exclude %{_datadir}/%{name}/themes/Flat.edj
%exclude %{_datadir}/%{name}/themes/default.edj

%{?suse_version:%files lang -f %{name}.lang}

%changelog
* Mon Mar 20 2023 Avindra Goolcharan <avindra@opensuse.org>
- Update to 1.13.0:
  * Colorshemes: add Fir Dark, Selenized Dark, Selenized Black,
    Selenized Light and Selenized White schemes
  * New translations: Indonesian
  * Translation updates for Catalan, Chinese (Simplified), Croatian,
    Dutch, French, German, Italian, Portuguese, Portuguese (Brazil),
    Russian, Spanish, Swedish, Turkish
  * Handle scale changes on the fly
  * Better named option to enable/disable typing sounds
  * Improved README file
  * The tyls tools now supports pls files
  * Fade the background of the terminal with the background color
    defined in the color scheme
  * Update the default theme to customize selection arrows
  * Update color schemes about selection arrows
  * Better documentation of the tyalpha tool
  * Fix issue when restoring the cursor state
  * Fix issue preventing some red color from being displayed
  * Cleanup the code base about C reserved identifiers
  * Code analyzed with Coverity 2022.06
  * Test code with some Coccinelle script in the GitHub's CI
  * Update the ChangeLog.theme file
- remove upstreamed fix-colorscheme-name-typo.patch
- rebase feature-flat-colorscheme.patch
* Mon May  2 2022 Simon Lees <sflees@suse.de>
- Removed debug code accidently left in
* Sun May  1 2022 Simon Lees <sflees@suse.de>
- Build "Flat" colorscheme as part of build process so that it gets
  the right name and is useable.
  * feature-flat-colorscheme.patch
* Thu Feb 17 2022 Simon Lees <sflees@suse.de>
- The default theme is now Flat, Dark will come back in a new package
- openSUSE Branding now has a colorscheme so use that as the default
- Fix colorscheme loading
  * fix-colorscheme-name-typo.patch
* Thu Feb 17 2022 Simon Lees <sflees@suse.de>
- Update to 1.12.1
  * New Deafult theme (Not the default in openSUSE)
  * Colorschemes generate their own configuration file, allowing
    for easy management of outside contributions
* Fri Nov 19 2021 Tomas Cech <sleep_walker@opensuse.org>
- bump to 1.11.0
* Tue Nov 17 2020 Simon Lees <sflees@suse.de>
- Add fix-desktop.patch to fix issues with desktop file
* Wed Aug 12 2020 Simon Lees <sflees@suse.de>
- Update to 1.8.1
  * Be stricter on which characters can be considered wide or not
  * Apply change about hiding mouse pointer after idle timeout on all terminals
* Tue Aug  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.0
  * Small framework to add unit tests
  * Display tooltips on when hovering color descriptions
  * Handle OSC 10/11 to change/get background and foreground colors
  * Reworked build system for testing and fuzzing
  * Use of switch-case constructs when home-made binary search was not
    efficient
  * Support EFL 1-22 or newer only
  * Larger list of word separators when doing word-selection
  * Reworked the Settings panel to add one panel on Mouse interactions
  * Handle Emoji characters as double-width, following Unicode 13.0
  * Fix issues detected by UndefinedBehavior Sanitizer
* Thu May 14 2020 Simon Lees <sflees@suse.de>
- Update to 1.7.0
  Additions:
  * Terminology is packaged on the `snapstore` at https://snapcraft.io/terminology
  * Add THEME.md, a documentation file on theming Terminology
  * Drag tabs to reorder them
  * Dragging tabs outside the tab bar can be used to create new splits
    or tabs
  * Add Croatian translation
  * Handle escape code used to display terminal program and version
  * Set environment variables TERM_PROGRAM and TERM_PROGRAM_VERSION
  Improvements:
  * Memory accounting of the backlogs. Seen under the Behavior tab on
    the Settings panel
  * Handle escape codes to stack titles
  * ''tyls'': add icon for ''flac'' files
  * Update the mild-based themes to be on-par feature-wise with the
    default theme
  * Tab selector shows background color
  * Controls panel is hidden when creating new tab or split
  * Enable Grouped Input from the Controls panel
  * Show special icon on tab when using Grouped Input
  * Add option to decide whether Grouped input goes to all tabs or only
    visible ones
  * Improve email/links detection when surrounded with special
    characters
  * Remove link underline when the link disappears
  * Share translucent/opacity setting across all instances
  * Use a default icon of each tab on the Settings toolbar
  * Update French, German, Italian and Serbian translations
  Removals:
  * Removed video settings
  Fixes:
  * Handle invalid values on OSC escape codes
  * Better handle reads and writes on EINTR/EAGAIN
* Fri Jan 31 2020 Tomas Cech <sleep_walker@opensuse.org>
- Update to 1.6.0
  Additions:
  * Show title tab on splits, depending on configuration
  * Show tabs that had a bell rang and had not been focused
  * Add wizard on new configuration to set scaling
  * Add scale configuration in the Settings panel
  * Add Polish translation
  Improvements:
  * Themes: make tab title readable based on theme default colors
  * Move the tab selector on the tab line
  * Be able to select and copy tabs
  * Better handle stalled unix socket when using one terminology with
    multiple instances
  * Change typop behavior to queue files in case there are multiple files to
    look at
  * Update Italian translation
  Fixes:
  * Fix live selections in the scrollback
  * Fix unchecking "auto-hide cursor" not working
  * Fix memory leaks related to looking for links under the mouse
  * Ensure Terminology compiles with EFL-1.20
  * Fix link detection over spaces
  * Fix tab selector no longer taking into account the new destination
  * Fix crash when using typop with multiple files
  * No longer set environment variable DESKTOP_STARTUP_ID as it may no
    longer be accurate
  * Allow tabs to be pasted
* Thu Aug 22 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to 1.5.0
  * Handle emoji has double-width character, introduced in Unicode 9.0.
  * Add option "Treat Emojis as double-width characters", on by default.
  * Hide cursor when idle, with parameter to set idle time
  * Add papercolor theme
  * Themes can now set background color through a color-class
  * Handle OSC-11 to report background color
  * Update Italian and French translations
  * Fix initial window size hints
  * Fix focus issues
* Tue May 28 2019 Tomas Cech <sleep_walker@opensuse.org>
- Update to 1.4.1:
  * Decode pasted string as UTF-8, fixing some characters being skipped
  * Fix theme to ensure default size is 80x24
  * Fix focus disappearing after going to Settings and back
  * Release v1.4.0
  * Add Continuous Integration on every push to the git repository
  * Add a test framework on escape code parsing and interpreting
  * Add more than 120 test files
  * Add support, along with tests, for the following escape codes: DSR-DIR,
    DSR-KBD, DSR-MSR, DSR-DECCKSR, DSR-OS, DSR-PP, DSR-UDK, DECSCLM, DECBI,
    DECFI, DECSACE, DECRARA, DECCRARA, DECIC, DECDC, DECCRA, DECST8C, DA3,
    DECSWBV
  * Add finer configuration on whether to activate links
  * Set environment variable WINDOWID
  * Selections only disappear if the underlaying content changes
  * When pasting a buffer, skip control characters as a security measure
  * Fixes, along with tests, on handling the following escape codes: VPR,
    DECERA, DECFRA, DSR-CPR, DCH, DECALN, DECAWM, IL, DL
  * Fixes, along with tests, on mouse reporting
  * Fixes on issues spotted by Coverity
  * Release v1.3.2
  * Clicking on links works again
  * Release v1.3.1
  * Add manpages on Terminology's helpers
  * Do not popup unknown media types (security issue)
  * Right-click on hyperlinks no longer crashes
  * Release v1.3.0
  * Hyperlink escape code support
  * Optimize escape code parsing by improving cell copies
  * Fix issues about settings panel
  * Do not pass input when tab selector is up
  * Escape code fixes
* Thu May 17 2018 avvissu@yandex.by
- Update to 1.2.1:
  * Fix focus issues when input was not registering
  * User-defined tab titles stay even when terminal wants change it
  * Themes no longer have glow effect when unfocused
- Change in 1.2.0:
  * New build system based on Meson
  * Add Nord theme
  * Add tysend tool and support escapes for sending single files
  * Grouped input support with Alt+g and Alt+Shift+g
  * Different cursor shapes: block (default), underline and bar
  * Support REP (Repeat preceding character) escape code
  * Support HPA (Horizontal Position Absolute) escape code
  * Support encircled escape code (SGR 52)
  * Support DECSCUSR (changing cursor shape)
  * When grabbing images through gravatar, use https
  * Shine level is configurable
  * Support EFL 1.20 or newer only
  * Approximate true-colors
- Swith to meson
- Replace category defined in the .desktop file
- Spec file cleanup
* Mon Oct  2 2017 avvissu@yandex.by
- Update to 1.1.1:
  * Fix issues with bottom margins
  * No longer add spurious newlines in selections in the backlog
  * No longer add space when running command from -e option
  * Fix -T option to set the title of the window
* Fri Sep 22 2017 avvissu@yandex.by
- Fix empty debug files on Mageia (add the -g flag)
* Thu Sep 21 2017 avvissu@yandex.by
- Add _git macro
- Use autogen.sh instead of autoreconf
- Auto-convert icons to hicolor
- Add package with translations
- Replace categories defined
- Add macros: _git, e_branding_version ,icon_theme_cache_post{un},
  desktop_database_post{un}
- Add files: AUTHORS ChangeLog NEWS
- Refresh the list of files
- Fix build on: SLE, Fedora, Mageia
- Spec file cleanup
* Wed Aug 23 2017 sflees@suse.de
- Update to 1.1.0
  * Additions:
  * Double-click on tab title to change it
  * Add option to disable focus-in/out animations and visuals
  * Add option to set current window size as default.
  * Support Right/Left Margins
  * Support for the DECERA/DECFRA escape codes
  * Move cursor to position on Click+Alt
  * Add bindings (Alt+Up/Down/Left/Right) to move around panes
  * Improvements:
  * Fallback to ~ or / when creating new terminal if current directory
    is not available
  * Support only efl >= 1.8.0
  * Harden escape codes decoding
  * Update all terms of a window when changing font (name or size)
  * Remove teamwork feature
  * Fixes:
  * Correctly handle the DECOM, DECSTBM, DECSLRM escape codes
  * Fix crash when resizing and there are tabs in content
  * Fix mouse motion and mouse button reporting
  * Set window sizing to 1px-step when having visible tabs
* Thu Jan 26 2017 sleep_walker@opensuse.org
- bump to 1.0.0
  Changes since 0.9.1:
    Additions:
  * Bold/Italic support (on by default)
    Improvement:
  * Add keybinding shift+home to go to the top of the backlog
  * Add keybinding shift+end to reset scroll
  * Add keybinding shift+left/right to switch between tabs
  * Add keybinding ctrl+alt+t to change terminal's title
  * Add ability to copy links on right-click menu
  * Font size can be changed by escape sequence
  * Rewrite link detection to be more efficient
  * Sanitize SHELL environment variable when using it
    Fixes:
  * Fix selections
  * Fixes about escape sequences managing tabs
  * Many fixes
- suppress errors in build log when edje_cc tries to reach DBus
* Thu Oct  1 2015 sleep_walker@opensuse.org
- bump to 0.9.1
  Changes since 0.9.0:
    Improvement:
  * Handle Ctrl-[2-8] when tab key bindings are removed
    Fixes:
  * Fix resizing issue
  * Fix solarized theme
- handle lang files correctly
* Tue Sep 15 2015 simon@simotek.net
- bump to 1.15.1
    Right-click on selection to be able to copy/open it
    Add key binding to fullscreen Terminology
    Add meta/hyper to key bindings
    Add option to always show miniview
    Add option to disable terminology escape codes
    Add -a option to tyls to display hidden files
    tybg without arguments restores the default wallpaper
    Escape closes media popup
    Terminology works on solaris
    Font selector now displays previews with current theme colors
    Try to get mime type when displaying URLs
    Do not use : as word separator but trim it from word selections
    Improved resizing handling
    Various bug fixes
* Mon Apr  6 2015 sleep_walker@suse.cz
- don't require evas-generic-loaders, it's not required for run,
  recommend it instead
* Fri Feb 20 2015 simon@simotek.net
- Some tidy ups while packaging rage
  * Should require emotion-generic-players
  * require efl 1.12 or later
* Mon Feb 16 2015 simon@simotek.net
- bump to 0.8.0
    Add a visual tab bar
    Gravatar support
    Add xterm "notification" support
    Display pre-edit text when composing
    Selection improvements
    Updated translations
    Various bug fixes
* Sun Oct 19 2014 simon@simotek.net
- Fix build by shipping locale files.
* Mon Oct 13 2014 sleep_walker@suse.cz
- bump to 0.7.0
  Changes since 0.6.1:
  - -------------------
  Additions:
  * Internationalization and Localization support
  * Options -s/--split to start terminology with multiple splits
  * Configurable key bindings
  * Add a panel to launch elementary_config
  Improvements:
  * Opacity level can be configured in translucent mode
  * Miniview: add position indicator
  * Improve media controls
  * Use a scalable font on default configuration
  * Usual round of improvements on terminal compatibility
  Fixes:
  * Fix issue with mute option
  * Various bug fixes
* Thu Jul  3 2014 sleep_walker@suse.cz
- bump to 0.6.1
  Changes since 0.6.0:
  - -------------------
  Additions:
  * Add .tga images to recognized files
  Improvements:
  * Reduced power consumption
  Fixes:
  * Fix issues with the teamwork modules and popups
* Wed Jul  2 2014 sleep_walker@suse.cz
- bump to 0.6.0
  Changes since 0.5.1:
  - -------------------
  Additions:
  * Make term switching cyclic
  * Add Mouse-Over focus
  * Fraktur support
  * Add option whether to detect links
  * Add option to disable the sound of the bell
  * Add new themes: Nyanology and smyck
  * Add miniview feature
  Improvements:
  * Improve terminal compatibility
  * Improve font selector to be able to select different font styles
  * Support rotation metadata on media files
  Fixes:
  * Various bug fixes
* Sun May 18 2014 sleep_walker@suse.cz
- bump to 0.5.1
  Fixes:
  * Make terminology compatible with upcoming efl/elm 1.10
  * Fix disappearing prompt on resize
* Sun Mar  9 2014 sleep_walker@suse.cz
- bump to 0.5.0
  Additions:
  * Color settings panel
  * Wallpaper settings panel
  * Load themes from ~/.config/terminology/themes/
  * Add a new theme: base16_ocean_dark
  Improvements:
  * Better default configuration
  * Improve terminal compatibility
  Fixes:
  * Many bugs fixes
* Tue Mar  4 2014 sleep_walker@suse.cz
- explicitly require efl (to get engine modules)
* Wed Feb 19 2014 simon@simotek.net
- upstream theme that provides terminology-theme-dft now conflicts with
  other providers
* Tue Dec 24 2013 simon@simotek.net
- Split themes into separate packages as terminology-theme-openSUSE
  can provide default.edj
* Thu Dec 19 2013 sleep_walker@suse.cz
- use Recommends only for *SUSE as that is SUSE specific RPM spec tag
* Mon Dec 16 2013 sleep_walker@suse.cz
- change to use pkgconfig dependencies
- beautify spec a bit
* Sat Dec  7 2013 simon@simotek.net
- Version 0.4.0 Release
  * compress backscroll
  * add audio keyboard
  * text reflow
  * full 256-colors support
  * improve terminal compatibility
  * improve selection
  * add a man page
  * add option to set geometry on start
  * be able to inline edje objects
  * bug fixes
* Sat Nov 30 2013 simon@simotek.net
- Updated to 0.4.0-alpha4
* Thu Oct 31 2013 simon@simotek.net
- Recommends new terminology-theme-openSUSE
* Tue Mar 26 2013 sleep_walker@suse.cz
- bump to 0.3.0
- remove dont-print-all.patch as it is already in new version
* Sat Jan 12 2013 sleep_walker@suse.cz
- remove terminology.desktop from tracking as the original is used again
* Thu Jan 10 2013 sleep_walker@suse.cz
- remove unused mandriva-mkstemps.patch from tracking
* Thu Jan 10 2013 cfarrell@suse.com
- license update: BSD-2-Clause and OFL-1.1
* Tue Jan  8 2013 sleep_walker@suse.cz
- remove autoupdate entries from changelog
- add tag to patch
* Thu Dec 27 2012 simon@simotek.net
- added dont-print-all.patch
  required until 0.3.0 stops printing every debug statement tio
  .xsession-errors
* Sat Dec 15 2012 sleep_walker@suse.cz
- fix license
- remove duplicates for SUSEs
- remove patch which reached upstream (mandriva-mkstemps.patch)
- fix URL
- update to 0.2.0 containing a lot of fixes
* Sun Dec  2 2012 sleep_walker@suse.cz
- mandriva-mkstemps.patch:
  use mkstemps only if available
* Mon Nov  5 2012 sleep_walker@suse.cz
- add desktop handling code
- disable silent rules
- spec cleanup
* Sat Jun 16 2012 sleep_walker@suse.cz
- fix git URL for auto updates
* Fri Jun 15 2012 sleep_walker@suse.cz
- let the terminology build against openSUSE_12.1
* Fri Jun 15 2012 sleep_walker@suse.cz
- let there be terminology
